CopyToClipboardExtensionEvent class

An extension event of type DevToolsExtensionEventType.copyToClipboard that is sent from an extension to DevTools asking DevTools copy content to the user's clipboard.

Inheritance

Constructors

CopyToClipboardExtensionEvent({required String content, String successMessage = defaultSuccessMessage})
CopyToClipboardExtensionEvent.from(DevToolsExtensionEvent event)
factory

Properties

content → String
no setter
data → Map<String, Object?>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Optional field to describe the source that created and sent this event.
finalinherited
successMessage → String
no setter
type → DevToolsExtensionEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultSuccessMessage → const String