ExtensionEventDirection enum

Describes the flow direction for a DevToolsExtensionEventType.

Some events are unidirecitonal and some are bidirectional.

Inheritance
Available extensions

Values

bidirectional → const ExtensionEventDirection

Describes events that can be sent both from DevTools to extensions and from extensions to DevTools.

toDevTools → const ExtensionEventDirection

Describes events that can be sent from extensions to DevTools, but not from DevTools to extensions.

toExtension → const ExtensionEventDirection

Describes events that can be sent from DevTools to extensions, but not from extensions to DevTools.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ExtensionEventDirection>
A constant List of the values in this enum, in order of their declaration.