ShowBannerMessageExtensionEvent class

An extension event of type DevToolsExtensionEventType.showBannerMessage that is sent from an extension to DevTools asking DevTools to post a banner message to the extension's screen using the DevTools banner message framework.

Inheritance

Constructors

ShowBannerMessageExtensionEvent({required String id, required String bannerMessageType, required String message, required String extensionName, bool ignoreIfAlreadyDismissed = true, bool dismissOnConnectionChanges = true})
ShowBannerMessageExtensionEvent.from(DevToolsExtensionEvent event)
factory

Properties

bannerMessageType → String
no setter
data → Map<String, Object?>?
finalinherited
dismissOnConnectionChanges → bool
Whether this message should be dismissed on app connection changes.
no setter
extensionName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignoreIfAlreadyDismissed → bool
no setter
message → String
no setter
messageId → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Optional field to describe the source that created and sent this event.
finalinherited
type → DevToolsExtensionEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited