ShowNotificationExtensionEvent class

An extension event of type DevToolsExtensionEventType.showNotification that is sent from an extension to DevTools asking DevTools to post a notification the the DevTools notification framework.

Inheritance

Properties

data → Map<String, Object?>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Optional field to describe the source that created and sent this event.
finalinherited
type → DevToolsExtensionEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited